@@ -1,5 +1,5 @@
-# from vimania.todos.cli import app
+from vimania.todos.cli import app
 # from vimania.vim_.vimania_manager import VimaniaManager
 
-__version__ = "1.0.0"
+__version__ = "1.0.1"
 # __all__ = ["VimaniaManager", "app"]
